{% extends "blogango/admin/base.html" %}
{% block title %}{{ _("Manage Entries") }}{% endblock %}
{% block contents %}
<h1>{{ _("Manage Entries") }}{% if author %} by {{author}}{% endif %}</h1>
	<table class="postlist">
	    <tbody>
		    <tr>
		      <th class="title">Title</th>
		      <th class="author">Author</th>
		      <th class="categories">Categories</th>
		      <th class="comments">Comments</th>
		      <th class="date">Date</th>
		    </tr>
		    {% for entry in entries %}
		        {% include "blogango/admin/entry_snippet.html" %}
		    {% endfor %}
        </tbody>
    </table>
  <form action="{% url "blogango_admin_entry_new" %}" method="get">
    <div class="actions">
      <input type="submit" value="{{ _('New Entry') }}">
    </div>
  </form>
{% endblock %}
