{% load blogango_filters analytics %}
{% blogango_extra_context %}
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>{% block title %} {{ blog.title }} {% endblock %}</title>
<link href="{{ STATIC_URL }}blogango/css/as_blog_styles.css" rel="stylesheet" type="text/css" />
<link href="{{ STATIC_URL }}blogango/css/prettify.css" rel="stylesheet" type="text/css" />
<link href='http://fonts.googleapis.com/css?family=Droid+Serif:regular,bold&subset=latin' rel='stylesheet' type='text/css'>
<link href='http://fonts.googleapis.com/css?family=Lobster' rel='stylesheet' type='text/css'>
<link href='http://fonts.googleapis.com/css?family=Molengo&subset=latin' rel='stylesheet' type='text/css'>
{% if feed_url %}
    <link rel="alternate" type="application/rss+xml" title="The Agiliq Blog - Django Web Development RSS Feed" href="{{feed_url}}" />
{% endif %}
{% if canonical_url %}
    <link rel="canonical" href='{{ canonical_url }}' />
{% endif %}
{# <link rel="pingback" href="{% url "xmlrpc" %}" /> #}
<link rel="pingback" href="{{ pingback_xmlrpc_url }}" />

</head>
<body onload="pretty_print()">
<!--BASE CONTAINER STARTS-->
<div id="mainpage_bg">
  <!--PAGE CONTAINER STARTS-->
  <div id="page_container">
    <!-- HEADER STARTS HERE -->
    <div id="header">
	  <a href="{% url "blogango_index" %}">
		<img src="{{ STATIC_URL }}blogango/images/agiliq_blog_logo.png" width="206" height="67" alt="Agiliq Solutions" />
	  </a>
	  <h2 class="message">
		We love designing and developing websites, but what really drives us is
		solving problems and cultivating strong relationships with our clients
	  </h2>
	</div>
    <!-- HEADER ENDS HERE -->
    <!-- BREADCRUMBS STARTS HERE -->
    <div id="breadcrumbs">
      <ul id="crumbs">
        <li><a href="/" rel="nofollow">Home</a></li>
		{% block breadcrumbs %}
        <li><a href="#">Main section</a></li>
        <li><a href="#">Sub section</a></li>
        <li>The page you are on right now</li>
		{% endblock %}
      </ul>
    </div>
    <!-- BREADCRUMBS STARTS HERE -->
    <!-- CONTENT BLOCK STARTS HERE -->
    <div id="content_block">
      <div class="leftpanel">
		{% block content %}

		{% endblock %}
      </div>
      <div class="rightpanel">
        {% if recents %}
        <div id="blogposts_block">
     	  <div class="block_title">Posts</div>
          <ul class="list">
			{% for recent in recents %}
				<li><a href="{{ recent.get_absolute_url }}" title='{{ recent.title }}'>{{ recent.title }}</a></li>
			{% endfor %}
          </ul>
        </div>
		{% endif %}

		{% if tags %}
        <div id="categories_block">
          <div class="block_title">Topics</div>
          <ul class="list_left">
			  {% for tag in tags %}
                  <li><a href="{% url "blogango_tag_details" tag.slug %}" class='{% cycle "left" "right" %}' rel="nofollow">{{ tag.name }}</a></li>
              {% endfor %}
          </ul>
          <div class="clear"></div>
        </div>
		{% endif %}
		{% if archive_months %}
        <!--ARCHIEVES STARTS HERE-->
        <div id="archives_block">
          <div class="block_title">Archives</div>
          <ul class="list_left">
			{% for month in archive_months %}
				<li><a href="{% url "blogango_archives" month|date:'Y' month|date:'b' %}" class='{% cycle "left" "right" %}' rel="nofollow">{{ month|date:'F Y' }}</a></li>
			{% endfor %}
          </ul>
          <div class="clear"></div>
        </div>
        <!--ARCHIEVES ENDS HERE-->
		{% endif %}
		{% if blogroll %}
		<!--BLOGROLL STARTS HERE-->
        <div id="archives_block">
          <div class="block_title">BLOG ROLL</div>
          <ul class="list_left">
			{% for br in blogroll %}
				<li><a href="{{ br.url }}">{{ br.text }}</a></li>
			{% endfor %}
          </ul>
          <div class="clear"></div>
        </div>
        <!--BLOGROLL ENDS HERE-->
		{% endif %}

      </div>
      <div class="clear"></div>
    </div>
    <!--  CONTENT BLOCK STARTS HERE -->
  </div>
  <!--PAGE CONTAINER ENDS-->
  <!--FOOTER CONTAINER STARTS-->
  <div id="footerbg">
	<span class='footertext'>&copy;COPYRIGHT AGILIQ SOLUTIONS</span>
  </div>
  <!--FOOTER CONTAINER ENDS-->
</div>
<!--BASE CONTAINER ENDS-->
<script type="text/javascript" src="{{ STATIC_URL }}blogango/js/jquery.min.js"></script>
<script type="text/javascript">
    function pretty_print(){
        $(document).ready(function() {

    // add prettyprint class to all <pre></pre> blocks
    var prettify = false;
    $("pre").each(function() {
        $(this).addClass('prettyprint');
        prettify = true;
    });

    // if code blocks were found, bring in the prettifier ...
    if ( prettify ) {
        $.getScript("{{ STATIC_URL }}blogango/js/prettify.js", function() { prettyPrint() });
    }
});
}
</script>
{% analytics %}
</body>
</html>
